@@ -4,7 +4,7 @@ from PIL import Image as img
 import base64
 from PIL.Image import Image
 import imagehash
-from imagehash import ImageHash
+from imagehash import ImageHash, hex_to_hash
 
 
 def __load_image(encoded_image: bytes) -> Union[Image, None]:
@@ -33,28 +33,28 @@ def hash_image(encoded_image: bytes) -> Union[ImageHash, None]:
     return imagehash.average_hash(image)
 
 
-def are_similar(reference_hash: ImageHash, other_hash: ImageHash) -> bool:
+def are_similar(reference_hash: str, other_hash: str) -> bool:
     """
     Returns True if two images are relatively similar.
 
-    :param reference_hash: An imagehash `ImageHash` object.
-    :param other_hash: An imagehash `ImageHash` object.
+    :param reference_hash: An hex string returned from str(ImageHash)
+    :param other_hash: An hex string returned from str(ImageHash)
     :return: True if similar. False otherwise.
     """
 
-    return abs(reference_hash - other_hash) <= 15
+    return abs(hex_to_hash(reference_hash) - hex_to_hash(other_hash)) <= 15
 
 
-def similarity(reference_hash: ImageHash, other_hash: ImageHash) -> int:
+def similarity(reference_hash: str, other_hash: str) -> int:
     """
     Returns how similar the hashes of two images are. Lower is more similar and 0 is equal.
 
-    :param reference_hash: An imagehash `ImageHash` object.
-    :param other_hash: An imagehash `ImageHash` object.
+    :param reference_hash: An hex string returned from str(ImageHash)
+    :param other_hash: An hex string returned from str(ImageHash)
     :return: The bit difference between two hashes
     """
 
-    return abs(reference_hash - other_hash)
+    return abs(hex_to_hash(reference_hash) - hex_to_hash(other_hash))
 
 
 # For testing:
@@ -73,6 +73,6 @@ def similarity(reference_hash: ImageHash, other_hash: ImageHash) -> int:
 #             encoded_image = base64.b64encode(image)
 #             calculated_hash = hash_image(encoded_image)
 #             print(f"{path}: {calculated_hash}")
-#             hashes.append(calculated_hash)
+#             hashes.append(str(calculated_hash))
 #
 #     print(are_similar(hashes[0], hashes[1]), similarity(hashes[0], hashes[1]))
